@@ -1,5 +1,5 @@
 #!/bin/sh
-exec perl -w -x $0 ${1+"$@"} # -*- mode: perl; perl-indent-level: 2; -*-
+exec perl -w -x $0 ${1+"$@"}
 #!perl -w
 
 
